##  Overview
Discovered flows is an optional capability that extends SAP discovery by identifying integration flows between your SAP systems. This feature uses data from SAP Cloud ALM's Integration & Exception Monitoring to help you:
  * Identify real integration flows between SAP systems
  * Spot missing or incomplete interface fact sheets
  * Support integration mapping and dependency analysis
  * Understand which systems are actively communicating


Discovered flows appear in the SAP discovery inbox with the classification "Discovered Flow". You can use them to create or link interface fact sheets.
![The SAP Discovery Inbox showing discovered integration flows and their statuses.](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loioa9ae1eac713d464ba86c9d9f4f74457a_LowRes.png)
Discovery Inbox with Discovered Flows
